@@ -10,7 +10,8 @@ __all__ = ['thread',
            'TimeoutError',
            'TaskCancelled']
 
-from .pebble import PebbleError, TaskCancelled, TimeoutError
-from .pebble import Task, synchronized
-from .process import process, process_pool, ProcessPool
-from .thread import thread, thread_pool, ThreadPool
+from .pebble import PebbleError, TaskCancelled, TimeoutError, Task
+from .process import ProcessPool
+from .thread import ThreadPool
+from .decorators import synchronized, thread, thread_pool
+from .decorators import process, process_pool
