@@ -24,7 +24,6 @@ from time import time, sleep
 from traceback import format_exc, print_exc
 from threading import Thread
 from collections import Callable, deque
-from functools import update_wrapper
 from multiprocessing import Process
 from multiprocessing.connection import Listener, Client
 try:  # Python 2
@@ -34,7 +33,6 @@ except:  # Python 3
     from queue import Queue, Empty
     from pickle import PicklingError
 
-from .thread import thread
 from .pebble import TimeoutError, Task
 
 ### platform dependent code ###
@@ -52,165 +50,7 @@ CLOSING = 2
 CREATED = 3
 
 
-def process(*args, **kwargs):
-    """Turns a *function* into a Process and runs its logic within.
-
-    A decorated *function* will return a *Task* object once is called.
-
-    If *callback* is a callable, it will be called once the task has ended
-    with the task identifier and the *function* return values.
-
-    """
-    def wrapper(function):
-        return Wrapper(function, timeout, callback)
-
-    if len(args) == 1 and not len(kwargs) and isinstance(args[0], Callable):
-        return Wrapper(args[0], 0, None)
-    elif not len(args) and len(kwargs):
-        timeout = kwargs.get('timeout', 0)
-        callback = kwargs.get('callback')
-
-        return wrapper
-    else:
-        raise ValueError("Decorator accepts only keyword arguments.")
-
-
-def process_pool(*args, **kwargs):
-    """Turns a *function* into a ProcessPool and runs its logic within.
-
-    A decorated *function* will return a *Task* object once is called.
-
-    If *callback* is a callable, it will be called once the task has ended
-    with the task identifier and the *function* return values.
-
-    """
-    def wrapper(function):
-        return PoolWrapper(function, workers, task_limit, queue, queueargs,
-                           initializer, initargs, callback, timeout)
-
-    if len(args) == 1 and not len(kwargs) and isinstance(args[0], Callable):
-        return PoolWrapper(args[0])
-    elif not len(args) and len(kwargs):
-        queue = kwargs.get('queue')
-        queueargs = kwargs.get('queueargs')
-        workers = kwargs.get('workers', 1)
-        callback = kwargs.get('callback')
-        timeout = kwargs.get('timeout', 0)
-        initargs = kwargs.get('initargs')
-        initializer = kwargs.get('initializer')
-        task_limit = kwargs.get('worker_task_limit', 0)
-
-        return wrapper
-    else:
-        raise ValueError("Decorator accepts only keyword arguments.")
-
-
-def trampoline(function, *args, **kwargs):
-    """Trampoline function for decorators."""
-    func = load_function(function)
-    return func(*args, **kwargs)
-
-
-def dump_function(function):
-    """Dumps the decorated function for pickling."""
-    try:
-        name = function.__name__
-        module = function.__module__
-        __import__(module)
-        mod = sys.modules[module]
-        getattr(mod, name)
-        return {'name': name, 'module': module}
-    except (ImportError, KeyError, AttributeError):
-        raise PicklingError(
-            "Can't pickle %r: it's not found as %s.%s" %
-            (function, module, name))
-
-
-def load_function(state):
-    """Loads the function and extracts it from its decorator."""
-    name = state.get('name')
-    module = state.get('module')
-    __import__(module)
-    mod = sys.modules[module]
-    decorated = getattr(mod, name)
-    return decorated._function
-
-
-class Wrapper(object):
-    def __init__(self, function, timeout, callback):
-        self._function = function
-        self._counter = count()
-        self._connection = None
-        self.timeout = timeout
-        self.callback = callback
-        update_wrapper(self, function)
-
-    def __del__(self):
-        if self._connection is not None:
-            self._connection.close()
-
-    @thread
-    def _handle_job(self, worker):
-        task = None
-
-        # wait for task to complete, timeout or to be cancelled
-        while task is None:
-            if worker.channel.poll(0.2):
-                task = worker.task_complete()
-            else:
-                task = worker.task_valid(time())
-        # run tasks callback
-        if task._callback is not None:
-            try:
-                task._callback(task)
-            except:
-                print_exc()
-
-        # join the process
-        worker.join()
-
-    def __call__(self, *args, **kwargs):
-        if self._connection is None:
-            self._connection = Listener(family=FAMILY)
-        # serialize decorated function
-        function = dump_function(self._function)
-        # attach decorated function to the arguments
-        args = list(args)
-        args.insert(0, function)
-        t = Task(next(self._counter), trampoline, args, kwargs,
-                 self.callback, self.timeout)
-        w = Worker(self._connection.address)
-        w.start()
-        w.finalize(self._connection)
-        w.schedule_task(t)
-        self._handle_job(self, w)
-
-        return t
-
-
-class PoolWrapper(object):
-    def __init__(self, function, workers=1, task_limit=0,
-                 queue=None, queueargs=None,
-                 initializer=None, initargs=None, callback=None, timeout=0):
-        self._function = function
-        self._pool = ProcessPool(workers, task_limit, queue, queueargs,
-                                 initializer, initargs)
-        self.timeout = timeout
-        self.callback = callback
-        update_wrapper(self, function)
-
-    def __call__(self, *args, **kwargs):
-        # serialize decorated function
-        function = dump_function(self._function)
-        # attach decorated function to the arguments
-        args = list(args)
-        args.insert(0, function)
-        return self._pool.schedule(trampoline, args=args, kwargs=kwargs,
-                                   callback=self.callback,
-                                   timeout=self.timeout)
-
-
-class Worker(Process):
+class ProcessWorker(Process):
     def __init__(self, address, limit=1, initializer=None, initargs=None):
         Process.__init__(self)
         self.address = address
@@ -433,8 +273,8 @@ class PoolMaintainer(Thread):
         pool = []
 
         for _ in range(self.workers - len(self.pool)):
-            worker = Worker(self.connection.address, self.limit,
-                            self.initializer, self.initargs)
+            worker = ProcessWorker(self.connection.address, self.limit,
+                                   self.initializer, self.initargs)
             worker.start()
             worker.finalize(self.connection)
             pool.append(worker)  # add worker to pool
